@@ -1,6 +1,8 @@
 #pragma once
-#include <catch2/catch.hpp>
 #include <panda/protocol/http.h>
+#include <catch2/catch_test_macros.hpp>
+#include <catch2/generators/catch_generators.hpp>
+#include <catch2/matchers/catch_matchers_string.hpp>
 
 using namespace panda;
 using namespace panda::protocol::http;
